@@ -731,6 +731,7 @@ class SignalFrame(QFrame):
         else:
             self.ui.stackedWidget.setCurrentWidget(self.ui.pageSignal)
             self.ui.gvSignal.scene_type = self.ui.cbSignalView.currentIndex()
+            self.scene_manager.mod_type = self.signal.modulation_type
             self.ui.gvSignal.redraw_view(reinitialize=True)
             self.ui.labelRSSI.show()
 
@@ -1062,6 +1063,7 @@ class SignalFrame(QFrame):
 
             self.undo_stack.push(modulation_action)
 
+            self.scene_manager.mod_type = txt
             if self.ui.cbSignalView.currentIndex() == 1:
                 self.scene_manager.init_scene()
                 self.on_slider_y_scale_value_changed()
@@ -1267,12 +1269,16 @@ class SignalFrame(QFrame):
                                                                   parameter_value=message_length_divisor)
             self.undo_stack.push(message_length_divisor_action)
 
-    @pyqtSlot()
-    def on_btn_advanced_modulation_settings_clicked(self):
+    def get_advanced_modulation_settings_dialog(self):
         dialog = AdvancedModulationOptionsDialog(self.signal.pause_threshold, self.signal.message_length_divisor,
                                                  parent=self)
         dialog.pause_threshold_edited.connect(self.on_pause_threshold_edited)
         dialog.message_length_divisor_edited.connect(self.on_message_length_divisor_edited)
+        return dialog
+
+    @pyqtSlot()
+    def on_btn_advanced_modulation_settings_clicked(self):
+        dialog = self.get_advanced_modulation_settings_dialog()
         dialog.exec_()
 
     @pyqtSlot()
